
# -*- coding: utf-8 -*-
import re
import sys

from pypeit.scripts.lowrdx_skyspec import LowRDXSkySpec

if __name__ == '__main__':
    sys.argv[0] = re.sub(r'(-script\.pyw?|\.exe)?$', '', sys.argv[0])
    sys.exit(LowRDXSkySpec.entry_point())
